/* 	

Analysis for cash drop experiment, using combined admin and svy data. 

*/

** -----------------------------------------------------------------------------
** PREAMBLE
** -----------------------------------------------------------------------------

	clear all
	set more off
	
	cap which estout
	if _rc net install estout
	
	global DIR_ROOT `c(pwd)'						// <------- change as needed

	* global OUTPUT "${DIR_ROOT}/output/${S_DATE}" 	// <------- change as needed
	global OUTPUT "${DIR_ROOT}/${S_DATE}" 			// <------- SPECIFY TARGET 
													// LOCATION FOR REGRESSION 
													// TABLES
	  cap mkdir "${OUTPUT}"
	  cap mkdir "${OUTPUT}/regs"
	  cap mkdir "${OUTPUT}/graphs"
	  
	* global DATA "${DIR_ROOT}/output" 				// <------- change as needed
	global DATA "${DIR_ROOT}" 						// <------- SPECIFY
													// LOCATION OF DATA SET
													
	* global CODE "${DIR_ROOT}/code"   				// <------- change as needed
	global CODE "${DIR_ROOT}"   					// <------- SPECIFY
													// LOCATION OF DO FILES
													
	* local log "${DIR_ROOT}/log"						// <------- change as needed
	local log "${DIR_ROOT}"
	
	cap log close
	log using "`log'/analysis.log", replace text
	  	
** -----------------------------------------------------------------------------
** -----------------------------------------------------------------------------

** ---START USER INPUT----------------------------------------------------------

** EXECUTION CONTROL

// control execution // 0 off / 1 on
	global baltests 	= 1
	global admin_sd 	= 1
	global mainregsvy 	= 1

	global figure_on 	= 0 // produce figures; but not tables 
		
** ---END USER INPUT------------------------------------------------------------
	
// Load combined data
	use "${DATA}/ddcs_pub.dta"
	
	egen tag_hh = tag(blid)
	
	tab treatmentgroup 
	tab treatmentgroup if tag_hh
	
// Define set of outcome vars

	global sd_sav	savNBS_st savform_st savinf_st ///
					savkind_st savfiOth_st savtot_st 
	global sd_plan 	plan_food unplan_food plan_non unplan_non 
	global sd_exp 	total food non durainvest socservfee // S.D. on exp (I/II)
	global sd_tempt tempt1 tempt2 tempt3 
	
	global dy_exp 	${sd_exp}
	global dy_plan 	${sd_plan}
	global dy_tempt ${sd_tempt}
	

	#d ; 
	global Ys  		
		${sd_exp} 	
		${sd_sav}	
		${sd_plan} 	
		${sd_tempt} 
		${dy_exp} 	
	;
	#d cr
				
	global Ys: list uniq global(Ys)
	di "`Ys'"
	
// Create baseline value vars and drop round 1 of panel
	 foreach y of varlist $Ys {
		local yv `y'_b1t99 
		qui by blid (round), sort: gen `yv'_pre = `yv'[1]
	 }
	 //
	drop if r1 // round 1 
		
	qui compress

// Specify all temp file names
	tempfile 	comb_all comb_1week comb_2week comb_delay ///
				comb_1week_immediate comb_2week_immediate ///
				comb_delay_dd comb_delay_cash
				
// save full file				
	save `comb_all'
	
// save different analysis data sets	
	drop if treatmentgroup==1 // control
	drop if inlist(treatmentgroup,2,3,4,5) & round==3 // 2nd week for +0, +1
	drop if inlist(treatmentgroup,6,7) & round==2 // 1st week for +8
	save `comb_1week'
	save `comb_delay'
	
	*tab treatmentgroup, su(total_b1t99)
		
	keep if inlist(treatmentgroup,2,3) // immediate 
	save `comb_1week_immediate'
	
	use `comb_delay'	
	keep if inlist(treatmentgroup,3,5,7) // dd
	save `comb_delay_dd'
		
	use `comb_delay'	
	keep if inlist(treatmentgroup,2,4,6) // cash 
	save `comb_delay_cash'

	** reload orginal data
	use `comb_all'
	drop if treatmentgroup==1 // control
	drop if inlist(treatmentgroup,2,3,4,5) & round==2 // +0, +1
	drop if inlist(treatmentgroup,6,7) // +8
	assert inlist(treatmentgroup,2,3,4,5) // +0, +1
	save `comb_2week'
	keep if inlist(treatmentgroup,2,3) // immediate 
	save `comb_2week_immediate'

** Start analysis
	clear

** -----------------------------------------------------------------------------
	// SUM STATS
	local bl_svy_vars hh_gender_b1t99 hh9_married_b1t99 hh_size_b1t99 BL_ag2_b1t99 BL_total_assets_b1t99 pca_b1t99 bankdist_b1t99 hyperbolic_b1t99 patientnow_b1t99 switchA_b1t99
	local exp1_vars total_b1t99_pre food_b1t99_pre non_b1t99_pre durainvest_b1t99_pre socservfee_b1t99_pre unplan_food_b1t99_pre unplan_non_b1t99_pre 
	local sav1_vars savNBS_st_b1t99_pre savform_st_b1t99_pre savinf_st_b1t99_pre savkind_st_b1t99_pre savfiOth_st_b1t99_pre savtot_st_b1t99_pre 	
	local bankint_vars actAny_pre_7d_int actAny_pre_90d_int valdeps_pre_90d_int valwith_pre_90d_int net_pre_90d_int 
	local balanceyvars `bl_svy_vars' `sav1_vars' `exp1_vars' `bankint_vars'	
	
	use `comb_1week' // is the same as `comb_delay'	
	tabstat `balanceyvars', stats(mean sd N p5 p10 p50 p90 p95) columns(statistics)
	
** -----------------------------------------------------------------------------
	// BALANCE
	if ${baltests}==1 include "${CODE}/sub_a_balance_v2"
	
** -----------------------------------------------------------------------------
	// MAKE TABLES main regression - admin

	** SAVINGS DEFAULT
	if ${admin_sd}==1 include "${CODE}/sub_a_admin_sd"
	
** -----------------------------------------------------------------------------	
	// MAKE TABLES main regression - svy 
	
	local spec_cluster cluster(blid)
	local spec_controls_exY0 __Iweek_* __Iz3com_*
	local spec_T_1week_DD DD_T1
	local spec_T_2week_DD DD_T2
	local spec_T_delay Post1_delay1 Post1_delay8 
	
	local reg_full_DD `spec_controls_exY0' `spec_T_full_DD' , `spec_cluster'
	local reg_1week_DD `spec_controls_exY0' `spec_T_1week_DD', `spec_cluster'
	local reg_2week_DD `spec_controls_exY0' `spec_T_2week_DD', `spec_cluster'
	local reg_delay `spec_controls_exY0' `spec_T_delay', `spec_cluster'
		
	** Main
	 if ${mainregsvy}==1 include "${CODE}/sub_a_svy_main_v4.do"

		
exit
	
	
	
	
